@@ -6,6 +6,8 @@ require Date::Format;
 require URI::Escape::XS;
 use Carp qw(confess cluck);
 
+our $VERSION = '1.00';
+
 our @EXPORT_OK;
 
 push @EXPORT_OK, 'is_object';
@@ -30,6 +32,26 @@ sub has_method
     );
 }
 
+# prototype, C implementation required
+push @EXPORT_OK, 'is_lvalue';
+sub is_lvalue
+{
+    my($method) = @_;
+    require attributes;
+    my $result = 0;
+    
+    my @attrs = attributes::get($method);
+    foreach my $attr (@attrs)
+    {
+        if( $attr eq 'lvalue' )
+        {
+            $result = 1;
+            last;
+        }
+    }
+    return $result;
+}
+
 # @todo This must be implemented with XS part (already written)
 push @EXPORT_OK, 'html_protect';
 our %HTML_PROTECT = (
@@ -292,4 +314,32 @@ sub escape{return URI::Escape::XS::encodeURIComponent(shift);}
 push @EXPORT_OK, 'unescape';
 sub unescape{return URI::Escape::XS::decodeURIComponent(shift);}
 
+our %BOOL_PROCESSORS = (
+    'SCALAR' => sub{ my $value = shift; return $$value; }
+    , 'HASH' => sub{ my $value = shift; return scalar keys(%$value); }
+    , 'ARRAY' => sub{ my $value = shift; return scalar @$value; }
+);
+
+push @EXPORT_OK, 'as_bool';
+sub as_bool
+{
+    my $value = shift;
+    my $value_type = ref $value;
+    
+    if( $value_type )
+    {
+        if( $BOOL_PROCESSORS{$value_type} )
+        {
+            $value = $BOOL_PROCESSORS{$value_type}->($value);
+        }
+        elsif( has_method( $value, 'as_bool' ) )
+        {
+            $value = $value->as_bool();
+        }
+    }
+    
+    return $value;
+}
+
+
 1;
\ No newline at end of file
